@@ -132,9 +132,7 @@ _glibtop_get_fsusage_read_write (glibtop *server, glibtop_fsusage *buf, const ch
         buf->read = sfs.f_syncreads + sfs.f_asyncreads;
         buf->write = sfs.f_syncwrites + sfs.f_asyncwrites;
 #endif
-	if (buf->read || buf->write) {
-                buf->flags |= (1 << GLIBTOP_FSUSAGE_READ) | (1 << GLIBTOP_FSUSAGE_WRITE);
-	}
+        buf->flags |= (1 << GLIBTOP_FSUSAGE_READ) | (1 << GLIBTOP_FSUSAGE_WRITE);
 }
 
 void
@@ -142,6 +140,8 @@ glibtop_get_fsusage_s(glibtop *server, glibtop_fsusage *buf, const char *path)
 {
 	struct statvfs fsd;
 
+	glibtop_init_r (&server, 0, 0);
+
 	memset (buf, 0, sizeof (glibtop_fsusage));
 
 	if (statvfs (path, &fsd) < 0)
