@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with LibGTop; see the file COPYING. If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
 #include <config.h>
@@ -36,34 +36,23 @@ static glibtop_sysinfo sysinfo = { .flags = 0 };
 static void
 init_sysinfo (glibtop *server)
 {
-	char* buffer;
+	char buffer [65536];
 	gchar ** processors;
 
 	if(G_LIKELY(sysinfo.flags)) return;
 
-	if (!g_file_get_contents(FILENAME, &buffer, NULL, NULL)) {
-		glibtop_error_io_r(server, "g_file_get_contents(%s)", FILENAME);
-	}
+	file_to_buffer(server, buffer, sizeof buffer, FILENAME);
 
 	/* cpuinfo records are seperated by a blank line */
 	processors = g_strsplit(buffer, "\n\n", 0);
 
-	g_free(buffer);
-
-	sysinfo.ncpu = 0;
-	for (char** this_proc = &processors[0]; *this_proc && **this_proc; this_proc++) {
-
-		if (sysinfo.ncpu >= GLIBTOP_NCPU) {
-			glibtop_warn_r(server, "Cannot deal with more than %d CPUs", GLIBTOP_NCPU);
-			break;
-		}
+	for(sysinfo.ncpu = 0;
+	    sysinfo.ncpu < GLIBTOP_NCPU && processors[sysinfo.ncpu] && *processors[sysinfo.ncpu];
+	    sysinfo.ncpu++) {
 
 		gchar **parts, **p;
-		if (g_strrstr (*this_proc, "processor" ) == NULL) {
-		  /* skip unknown paragraph */
-		  continue;
-		}
-
+        if (g_strrstr (processors[sysinfo.ncpu], "processor" ) == NULL) 
+            continue;
 		glibtop_entry * const cpuinfo = &sysinfo.cpuinfo[sysinfo.ncpu];
 
 		cpuinfo->labels = g_ptr_array_new ();
@@ -75,7 +64,7 @@ init_sysinfo (glibtop *server)
 							g_free, g_free);
 
 		/* "<key>    : <value>" */
-		parts = g_strsplit_set(*this_proc, ":\n", 0);
+		parts = g_strsplit_set(processors[sysinfo.ncpu], ":\n", 0);
 
 		for(p = parts; *p && *(p+1); p += 2) {
 
@@ -96,7 +85,6 @@ init_sysinfo (glibtop *server)
 
 		g_free(parts);
 
-		sysinfo.ncpu++;
 	}
 
 	g_strfreev(processors);
