@@ -15,17 +15,14 @@
 
    You should have received a copy of the GNU General Public License
    along with LibGTop; see the file COPYING. If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
 #include <config.h>
 #include <sys/types.h>
-#include <sys/sysctl.h>
 #include <glibtop.h>
 #include <glibtop/open.h>
-#include <glibtop/cpu.h>
-#include <glibtop/error.h>
 
 #include <glibtop_private.h>
 
@@ -35,24 +32,5 @@ glibtop_open_s (glibtop *server, const char *program_name,
 		const unsigned long features,
 		const unsigned flags)
 {
-	int ncpus = 1;
-	int mib[2] = { CTL_HW, HW_NCPU };
-	size_t len;
-
-	len = sizeof(ncpus);
-	if (sysctl(mib, 2, &ncpus, &len, NULL, 0) != 0)
-		printf("Couldn't determine hw.ncpu.\n");
-
-	server->real_ncpu = ncpus - 1;
-	server->ncpu = MIN(GLIBTOP_NCPU - 1, server->real_ncpu);
-
 	server->os_version_code = OpenBSD;
-
-	if (server->real_ncpu != server->ncpu) {
-		glibtop_warn_r(server,
-			"This machine has %d CPUs, "
-			"%d are being monitored.",
-			server->real_ncpu + 1,
-			server->ncpu + 1);
-	}
 }
