@@ -1,5 +1,3 @@
-/* $OpenBSD: uptime.c,v 1.6 2011/06/01 07:24:49 jasper Exp $	*/
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -39,7 +37,7 @@ static const unsigned long _required_cpu_flags =
 /* Init function. */
 
 void
-_glibtop_init_uptime_p (glibtop *server)
+_glibtop_init_uptime_s (glibtop *server)
 {
 	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
 }
@@ -47,7 +45,7 @@ _glibtop_init_uptime_p (glibtop *server)
 /* Provides uptime and idle time. */
 
 void
-glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
+glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 {
 	time_t now;
 	int mib[2];
@@ -65,7 +63,7 @@ glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
 		buf->boot_time = boottime.tv_sec;
 	}
 
-	glibtop_get_cpu_p (server, &cpu);
+	glibtop_get_cpu_s (server, &cpu);
 
 	/* Put something clever in buf->idletime: CP_IDLE. */
 	buf->idletime = (double) cpu.idle / (double) cpu.frequency;
